LineMetrics class

Constructors

LineMetrics({required LyricLine line, required double height, List<WordMetrics>? words, required double width, required double activeWidth, required double activeHeight, required double translationWidth, required double translationHeight, required List<LineMetrics> activeMetrics, required List<LineMetrics> metrics, required TextPainter textPainter, required TextPainter activeTextPainter, required TextPainter textMaskPainter, required TextPainter activeMaskPainter, required TextPainter translationTextPainter})

Properties

activeHeight → double
final
activeMaskPainter → TextPainter
final
activeMetrics → List<LineMetrics>
final
activeTextPainter → TextPainter
final
activeWidth → double
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
line → LyricLine
final
metrics → List<LineMetrics>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textMaskPainter → TextPainter
final
textPainter → TextPainter
final
translationHeight → double
final
translationTextPainter → TextPainter
final
translationWidth → double
final
width → double
final
words → List<WordMetrics>?
final

Methods

copyWith({LyricLine? line, double? height, double? width, double? activeWidth, double? activeHeight, double? translationWidth, double? translationHeight, List<LineMetrics>? activeMetrics, List<LineMetrics>? metrics, TextPainter? textPainter, TextPainter? activeTextPainter, TextPainter? textMaskPainter, TextPainter? activeMaskPainter, TextPainter? translationTextPainter, List<WordMetrics>? words}) → LineMetrics
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited