LyricModel class

整首歌词

Constructors

LyricModel({Map<String, String>? tags, required List<LyricLine> lines})

Properties

album → String
no setter
artist → String
no setter
by → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
idTags → Map<String, String>
final
lines → List<LyricLine>
final
offset → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
no setter

Methods

copyWith(Map<String, String>? tags, List<LyricLine>? lines) → LyricModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited