FadeRange class

渐隐范围 / Fade range

Constructors

FadeRange({required double top, required double bottom})

Properties

bottom → double
底部渐隐值 / Bottom fade value
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → double
顶部渐隐值 / Top fade value
final

Methods

copyWith({double? top, double? bottom}) → FadeRange
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override