LyricLayout class

Constructors

LyricLayout.compute(LyricModel model, LyricStyle style, Size viewSize)
factory
LyricLayout.updatePainters(LyricLayout layout)
factory

Properties

activeAnchorPosition → double
final
hashCode → int
The hash code for this object.
no setterinherited
metrics → List<LineMetrics>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectionAnchorPosition → double
final
style → LyricStyle
final
viewSize → Size
final

Methods

anchorAdjustmentOffsetY(int index, int activeIndex) → double
anchorOffsetY(int index, bool isHighlight, double? lineHeight, MainAxisAlignment? alignment) → double
contentHeight(int highlightIndex) → double
copyWith(LyricStyle style) → LyricLayout
getLineHeight(bool isHighlight, int index) → double
lineOffsetY(int index, int activeIndex, double anchorPosition, MainAxisAlignment alignment) → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

buildHighlightMaskTextSpan(TextSpan source) → TextSpan
createHighlightMaskPainter(TextPainter sourcePainter, double maxWidth) → TextPainter