LyricScrollAnimationConfig class

滚动动画配置 / Scroll animation configuration

Constructors

LyricScrollAnimationConfig({required Duration duration, required Curve curve})
const

Properties

curve → Curve
滚动动画曲线 / Scroll animation curve
final
duration → Duration
滚动动画时长 / Scroll animation duration
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited